@@ -1,5 +1,5 @@
 use super::{InformationSchema, SchemaQueryBuilder};
-use crate::sqlx_types::{mysql::MySqlRow, Row};
+use crate::sqlx_types::mysql::MySqlRow;
 use sea_query::{Expr, Iden, Order, Query, SeaRc, SelectStatement, Value};
 
 #[derive(Debug, sea_query::Iden)]
@@ -76,6 +76,7 @@ impl SchemaQueryBuilder {
 #[cfg(feature = "sqlx-mysql")]
 impl From<&MySqlRow> for IndexQueryResult {
     fn from(row: &MySqlRow) -> Self {
+        use crate::sqlx_types::Row;
         Self {
             non_unique: row.get(0),
             index_name: row.get(1),
