@@ -7,10 +7,10 @@ impl ForeignKeyInfo {
         key.name(&self.name)
             .to_tbl(Alias::new(&self.referenced_table));
         for column in self.columns.iter() {
-            key.from_col(Alias::new(&column));
+            key.from_col(Alias::new(column.as_str()));
         }
         for ref_col in self.referenced_columns.iter() {
-            key.to_col(Alias::new(&ref_col));
+            key.to_col(Alias::new(ref_col.as_str()));
         }
         key.on_update(match self.on_update {
             ForeignKeyAction::Cascade => sea_query::ForeignKeyAction::Cascade,
