@@ -15,7 +15,15 @@ pub struct Schema {
 pub struct TableDef {
     pub info: TableInfo,
     pub columns: Vec<ColumnInfo>,
-    pub constraints: Vec<Constraint>,
-    pub of_type: Option<Type>,
-    pub inherets: Vec<String>,
+
+    pub check_constraints: Vec<Check>,
+    pub not_null_constraints: Vec<NotNull>,
+    pub unique_constraints: Vec<Unique>,
+    pub primary_key_constraints: Vec<PrimaryKey>,
+    pub reference_constraints: Vec<References>,
+    pub exclusion_constraints: Vec<Exclusion>,
+    // FIXME: Duplication? TableInfo also have of_type
+    // pub of_type: Option<Type>,
+    // TODO:
+    // pub inherets: Vec<String>,
 }
